pricing_for

Function pricing_for 

pub fn pricing_for(model: &str) -> Option<ModelPricing>
Returns pricing for a model by looking it up in the bundled providers.toml. Returns None if the model is not listed or has no pricing field.