pub struct AgentPool { /* private fields */ }Expand description
An agent pool manages multiple agents with different roles.
Implementations
Sourceimpl AgentPool
impl AgentPool
pub fn new(provider: Arc<dyn LlmProvider>, config: Config) -> Self
pub fn memory(&self) -> &SharedMemory
pub fn bus(&self) -> &MessageBus
pub fn add_role(&mut self, role: AgentRole)
pub fn get_role(&self, name: &str) -> Option<&AgentRole>
pub fn role_names(&self) -> Vec<&str>
pub fn role_count(&self) -> usize
Sourcepub fn remove_role(&mut self, name: &str) -> bool
pub fn remove_role(&mut self, name: &str) -> bool
Remove a role from the pool. Returns true if the role existed.
pub async fn run_with_role( &self, role_name: &str, goal: &str, ) -> Result<TurnOutcome, Error>
Sourcepub async fn send_task(&self, from: &str, to: &str, content: &str)
pub async fn send_task(&self, from: &str, to: &str, content: &str)
Send a task message from one agent role to another.
Sourcepub async fn send_result(&self, from: &str, to: &str, content: &str)
pub async fn send_result(&self, from: &str, to: &str, content: &str)
Send a result message from one agent role to another.