parse_skill_meta

Function parse_skill_meta 

pub fn parse_skill_meta(
    content: &str,
    dir_path: &Path,
) -> (String, String, SkillMode, Vec<String>, String, Vec<String>, Vec<SkillParam>)
Parse YAML frontmatter (if present) from skill content.

Returns (name, description, mode, triggers, hint, params). If frontmatter is absent, falls back to using the parent directory name and first non-empty Returns (name, description, mode, triggers, hint, depends_on, params). If frontmatter is absent, falls back to using the parent directory name and first non-empty line, with default mode (Manual), empty triggers, empty hint, and empty depends_on.