PolicyToolSetProvider

Struct PolicyToolSetProvider 

pub struct PolicyToolSetProvider {
    pub policy: PolicyConfig,
    /* private fields */
}
ToolSetProvider that wraps the default registry with an L1 policy config.

The policy is stored in the registry for tools to query at call time via registry.policy(). It does not automatically enforce anything by itself; individual tools (e.g. run_shell) are responsible for calling registry.policy().check_shell(...) before executing.

Fields

policy: PolicyConfig

The L1 policy to attach to the built registry.

Implementations

Source

impl PolicyToolSetProvider

pub fn new( workspace: PathBuf, shell_timeout_secs: u64, skills: Vec<Skill>, policy: PolicyConfig, ) -> Self

pub fn restrictive( workspace: PathBuf, shell_timeout_secs: u64, skills: Vec<Skill>, ) -> Self