pub struct FsPolicy {
pub read_allow: Vec<String>,
pub write_allow: Vec<String>,
pub deny: Vec<String>,
}Expand description
Filesystem access policy.
Fields
read_allow: Vec<String>If non-empty, only paths whose canonical form starts with one of these prefixes are allowed for reading.
write_allow: Vec<String>If non-empty, only paths whose canonical form starts with one of these prefixes are allowed for writing.
deny: Vec<String>Paths explicitly denied for any access (overrides allow lists).