Tool to run a script from a skill’s scripts/ directory.
Finds the named script within a named skill, executes it with optional arguments, and returns the combined stdout+stderr output.
Structs
- RunSkill
Script - Tool to run a script from a skill’s scripts/ directory.