pub fn dispatch(app: &mut App, key: KeyEvent) -> Option<UserAction>Expand description
Dispatch a key event onto the app state. Returns an optional
UserAction the caller must forward to the agent worker.
pub fn dispatch(app: &mut App, key: KeyEvent) -> Option<UserAction>Dispatch a key event onto the app state. Returns an optional
UserAction the caller must forward to the agent worker.