pub fn load_layered_permissions(workspace: &Path) -> LayeredPermissionsConfigExpand description
Load layered permissions from user config and project config.
Resolution order (highest priority first):
- Session layer (empty, filled at runtime via Goal 196)
- Project layer (
.recursive/config.tomlin the workspace) - User layer (
~/.recursive/config.toml)
The Session layer is always present (even if empty) so that runtime rule updates can be written to it.