pub struct PolicyToolSetProvider {
pub policy: PolicyConfig,
/* private fields */
}Expand description
ToolSetProvider that wraps the default registry with an L1 policy config.
The policy is stored in the registry for tools to query at call time via
registry.policy(). It does not automatically enforce anything by itself;
individual tools (e.g. run_shell) are responsible for calling
registry.policy().check_shell(...) before executing.
Fields
policy: PolicyConfigThe L1 policy to attach to the built registry.
Implementations
Sourceimpl PolicyToolSetProvider
impl PolicyToolSetProvider
pub fn new( workspace: PathBuf, shell_timeout_secs: u64, skills: Vec<Skill>, policy: PolicyConfig, ) -> Self
Sourcepub fn restrictive(
workspace: PathBuf,
shell_timeout_secs: u64,
skills: Vec<Skill>,
) -> Self
pub fn restrictive( workspace: PathBuf, shell_timeout_secs: u64, skills: Vec<Skill>, ) -> Self
Create with PolicyConfig::default_restrictive policy.