Module load_skill

Module load_skill 

Tool to load a skill’s content by name.

Supports loading the main SKILL.md body, or an individual reference document from the skill’s refs/ directory via the optional ref parameter, or a named section from the skill body via the optional section parameter. Also supports parameter substitution via the params object.

When loading a skill (without ref or section), any skills listed in its depends_on frontmatter field are resolved recursively (up to 3 levels deep) and prepended to the output. Circular dependencies are detected and skipped with a warning.

Structs

LoadSkill
Tool to load a skill’s SKILL.md body content, or a specific ref document, or a named section.