Module run_skill_script

Module run_skill_script 

Tool to run a script from a skill’s scripts/ directory.

Finds the named script within a named skill, executes it with optional arguments, and returns the combined stdout+stderr output.

Structs

RunSkillScript
Tool to run a script from a skill’s scripts/ directory.